/**
 * Form 0.0.1
 * Ratchet forms module
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

var toolbox = require( 'compose-toolbox' )

// Public API function
var form = function( element, settings ) {

  // Overridable defaults
  var defaults = {}

  // Parameter variables
  var selector = document.querySelector( element ) || document.querySelector( 'form' );

  // Only run if selector exists
  if ( !selector ) return false;

  // Scoped variables
  var options  = toolbox.merge( defaults, settings ),
      rangeEls = document.querySelectorAll( 'input[type=range]' ),
      tickEls  = document.querySelectorAll( 'input[type=checkbox], input[type=radio]' ),
      docBody  = document.body;

  // Prevent non-numeric characters in number fields
  toolbox.event.on( docBody, 'keypress', 'input[type=number]', restrictInput )

  // Run delegated `on input` listener
  //toolbox.event.on( docBody, 'input', '[type=range]', rangeHandler )

  // Loop over any range inputs that are present
  //for ( var rangeIndex = 0; rangeIndex < rangeEls.length; rangeIndex++ ) {

    // And run their handler function explicitly at runtime
    //rangeHandler( rangeEls[ rangeIndex ] )

  //}

  // Keydown handler function
  function restrictInput( event ) {

    // If user typing in an input[type=number] and enters non-numeric characters
    if ( event.which < 48 || event.which > 57 ) {

      // Supress them
      event.preventDefault();

    }

  }

  // Range input hander function
  function rangeHandler( event ) {

    // Define local variable(s)
    var currValue  = rangeEls.value,
        maxValue   = rangeEls.max,
        minValue   = rangeEls.min,
        percValue  = currValue / maxValue * 100;

    // Define target element
    var element = ( event.target ) ? event.target : event;

    // Only run on range inputs
    if ( element.type !== 'range' ) {
      return false;
    }

    // Calculate percentage value
    var percValue = ( element.max ) ? element.value / element.max * 100 : element.value / 100 * 100;

    // Style bar accordingly
    element.style.backgroundImage = 'linear-gradient(90deg, #c3d4e4 ' + percValue + '%, #ffffff ' + percValue + '%)';

  }

};

// Public API
module.exports = form;
