/**
 * Swap.js 0.0.2
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

// Transport
;( function( root, factory ) {
  if ( typeof define === 'function' && define.amd ) {
    define( factory );
  } else if ( typeof exports === 'object' ) {
    module.exports = factory;
  } else {
    root.swap = factory( root );
  }
})( this, function( root ) {

  'use strict';

  var triggers = document.querySelectorAll( '.swap-trigger' );

  if ( triggers.length ) {

    // Assignment
    var location = window.location.hash;

    // Swap function
    var swap = function( trigger, target ) {

      // Find all current `selected` class elements
      var currentSelection = document.querySelectorAll( '.selected' );

      // And deselect them
      for ( var i = 0; i < currentSelection.length; i++ ) {
        currentSelection[ i ].classList.remove( 'selected' );
      }

      // Select our new elements
      trigger.classList.add( 'selected' );
      target.classList.add( 'selected' );
    };

    // Get current window hash
    var getHash = function() {
      return location.split( '#' )[ 1 ];
    };

    // Get link target hash
    var getLinkTarget = function( link ) {
      return link.href.split( '#' )[ 1 ];
    };

    // Hash check function
    var hashCheck = function( event ) {

      // If no hash
      if ( !location ) {

        // Assign first element(s) variables
        var firstTrigger = document.querySelector( '.swap-trigger' ),
            firstTarget  = document.querySelector( '.swappable' );

        // And select them
        swap( firstTrigger, firstTarget );

      // Otherwise
      } else {

        // Stop default anchor tag jump
        window.scrollTo(0, 0);

        // Assign appropriate element(s) variables
        var loadedTarget  = document.querySelector( '#' + getHash() ),
            loadedTrigger = document.querySelector('[href="#' + getHash() + '"]' );

        // And select them
        swap( loadedTrigger, loadedTarget );

      }

    };

    // Click handler function
    var clickHandler = function( event ) {

      // Prevent default behavior
      event.stopPropagation();
      event.preventDefault();

      // Local assignment
      var triggerElem = this,
          linkTarget  = getLinkTarget( triggerElem ),
          targetElem  = document.querySelector( '#' + linkTarget );

      // Select the appropriate elements
      swap ( triggerElem, targetElem );

      // Replace the hash
      history.replaceState( null, '', '#' + linkTarget );

    };

    // Run hash check on window load
    window.addEventListener( 'load', hashCheck, false );

    // Iterate over each swap trigger
    for ( var i = 0; i < triggers.length; i++ ) {

      // And attach our click listener
      triggers[ i ].addEventListener( 'click', clickHandler, false );

    }

  }

});