/**
 * Text Counter 0.0.1
 * Count & display number of chars/words in a textarea
 * @author Matt Gillespie (@savethetweets) & Kyle Foster (@hkfoster)
 * @license MIT
**/

;( function( root, factory ) {
  if ( typeof define === 'function' && define.amd ) {
    define( factory );
  } else if ( typeof exports === 'object' ) {
    module.exports = factory;
  } else {
    root.textCounter = factory( root );
  }
})( this, function( root ) {

  'use strict';

  // Public API function
  var exports = function( element, settings ) {

    // Parameter variables
    var
      selector = document.querySelector( element ),
      defaults = {
        defaultMsg : 'characters available',
        type       : 'characters',
        successMsg : null,
        closeCount : 20,
        value      : 140
      };

    // Only run if selector exists
    if ( !selector ) return false;

    // Scoped variables
    var
      options      = compose.extend( defaults, settings ),
      progressElem = selector.querySelector( 'progress' ),
      counterInput = selector.querySelector( 'textarea' ),
      targetCount  = progressElem.value || options.limit,
      currentCount = 0,
      counterLabel,
      labelValue;

    // Create and insert progress label span
    compose.insertAfter( compose.makeNode( '<span>' + options.value + '&nbsp;' + options.defaultMsg + '</span>' ), progressElem );

    // Cache progress span
    counterLabel = progressElem.nextElementSibling;

    // Attach input listener
    counterInput.addEventListener( 'keyup', updateProgress, false );

    // Update progress function
    function updateProgress( event ) {

      // Update current count based on words or characters
      currentCount = ( options.type === 'words' ) ? currentCount = compose.wordCount( event.target.value ) : currentCount = event.target.value.length;

      // Compare current count to target count and set label value
      labelValue = targetCount - currentCount;

      // Set progress element’s value accordingly
      progressElem.value = labelValue;

      // If close count value is set and label value falls below it
      if ( options.closeCount && labelValue <= options.closeCount ) {

        // Apply `.danger` class to label
        counterLabel.classList.add( 'danger' );

      // Otherwise
      } else {

        // Remove `.danger` class from label
        counterLabel.classList.remove( 'danger' );

      }

      // If success message is set, trigger it … otherwise display negative text count
      counterLabel.textContent = ( options.successMsg && labelValue <= 0 ) ? options.successMsg : labelValue + ' ' + options.defaultMsg;

    }

  };

  // Public API
  return exports;

});