/**
 * Collapse 0.0.1
 * Easily create expandable excerpts
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

 ;( function( root, factory ) {
  if ( typeof define === 'function' && define.amd ) {
    define( factory );
  } else if ( typeof exports === 'object' ) {
    module.exports = factory;
  } else {
    root.collapse = factory( root );
  }
})( this, function( root ) {

  'use strict';

  // Public API function
  var exports = function( element, settings ) {

    // Parameter variables
    var
      selectors = document.querySelectorAll( element ),
      defaults  = {
        expandText   : 'Show more',
        collapseText : 'Show less',
        triggerText  : '{{more}}'
      };

    // Only run if selector exists
    if ( !selectors ) return false;

    // Scoped variables
    var
      options = compose.extend( defaults, settings ),
      state   = {};

    // Loop over expandable elements
    for ( var i = 0; i < selectors.length; i++ ) {

      // Scoped variables
      var
        selector  = selectors[ i ],
        original  = selector.innerHTML,
        expanded  = original + '<a class="expand" href="#">' + options.collapseText + '</a>',
        collapsed = original.split( options.triggerText )[ 0 ] + '&hellip; <a class="expand" href="#">' + options.expandText + '</a>';

      // Set excerpt text
      selector.innerHTML = collapsed;

      // Set index data attribute
      selector.dataset.idx = i;

      // Populate state reference object
      state[ i ] = {
        'expanded'  : expanded,
        'collapsed' : collapsed
      };

    }

    // Attach click listener
    document.body.addEventListener( 'click', clickHandler, false );

    // Click handler function
    function clickHandler( event ) {

      // Only run on `rel=expand` links
      if ( event.target.className !== 'expand' ) return false;

      // Prevent default behavior
      event.preventDefault();

      // Scoped variables
      var expandable  = compose.getClosest( event.target, element ),
          stateObject = state[ expandable.dataset.idx ];

      // Toggle between excerpt and full text
      expandable.innerHTML = ( expandable.innerHTML === stateObject.expanded ) ? stateObject.collapsed : stateObject.expanded;

      // Toggle between expand and collapse link text
      event.target.textContent = ( event.target.textContent === options.expandText ) ? options.collapseText : options.expandText;

    }

  };

  // Public API
  return exports;

});