/**
 * Lightbox 0.0.1
 * A simple lightbox module
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

// Dependencies
var toolbox    = require( 'compose-toolbox' ),
    Event      = toolbox.event,
    getClosest = toolbox.getClosest,
    loader     = require( 'compose-loader' ),
    modal      = require( './modal' );

// Public API function
var lightbox = function( selector, settings ) {

  // Apply default selector selector
  selector = selector || 'a[href$=jpg] ,a[href$=png], a[href$=gif], a[href$=svg]';

  // Overridable defaults
  var defaults = {
    initWidth : '700px'
  },

  // Scoped variables
  options    = Object.assign( {}, defaults, settings ),
  widthQuery = window.matchMedia( '(min-width: ' + options.initWidth + ')' );

  // Call listener function explicitly at run time
  queryHandler( widthQuery );

  // Attach listener function to listen in on state changes
  widthQuery.addListener( queryHandler );

  // Media query handler function
  function queryHandler( condition ) {

    // If media query matches
    if ( condition.matches ) {

      var mediaLinks = document.querySelectorAll( selector );

      if ( mediaLinks.length ) {

        for ( var i = 0; i < mediaLinks.length; i++ ) {
          document.body.insertAdjacentHTML( 'beforeend', '<link rel="prefetch" href="' + mediaLinks[ i ].href + '"/>' );
        }

      }

      // Dat modal doh
      modal( selector, function( event ) {

        var mediaLink    = getClosest( event.target, selector ),
            modalContent = document.querySelector( '[data-modal-content]' ),
            lightboxFigure,
            lightboxContent;

        // If Youtube embed
        if ( mediaLink.href.indexOf( 'youtu' ) > -1 ) {

          modalContent.insertAdjacentHTML( 'beforeend', '<figure class="lightbox viewport-embed"><iframe src="' + mediaLink.href + '" frameborder="0" allowfullscreen></iframe></figure>' );
          modalContent.querySelector( '.lightbox' ).classList.add( 'loaded' );

        // Otherwise
        } else {

          modalContent.insertAdjacentHTML( 'beforeend', '<figure class="lightbox"><img src="" alt=""></figure>' );

          lightboxContent = modalContent.querySelector( '.lightbox img' );
          lightboxFigure  = lightboxContent.parentNode;

          lightboxContent.addEventListener( 'load', function( event ) {
            lightboxFigure.classList.add( 'loaded' );
          }, false );

          lightboxContent.addEventListener( 'error', function( event ) {
            lightboxFigure.classList.add( 'loaded' );
            lightboxFigure.removeChild( lightboxContent );
            lightboxFigure.innerHTML = 'Content not found :(';
          }, false );

          lightboxContent.setAttribute( 'src', mediaLink.href );

        }

      });

    } else {

    }

  }

};

// Public API
module.exports = lightbox;