/**
 * Notice 0.0.1
 * Compose notice module
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

var toolbox = require( 'compose-toolbox' )

// Public API function
var notice = function( element, settings ) {

  // Overridable defaults
  var defaults = {
    noticeName    : 'notice',
    noticeClass   : 'notice',
    noticeMessage : '[your notice message here]'
  };

  // Scoped variables
  var options    = toolbox.merge( defaults, settings ),
      selector   = document.querySelector( element ),
      cookieName = 'dismiss-' + options.noticeName,
      button     = selector.querySelector( '.' + options.noticeClass + ' .close-btn' );

  // Only run if selector exists & no dismiss cookie is found
  if ( !selector || getCookie( cookieName ) ) return false;

  // Uncomment for development
  // deleteCookie( cookieName );

  // Create and append notice
  var html = '<aside class="' + options.noticeClass + '">' + options.noticeMessage + '<a href="#?" class="close-btn"></a></aside>'
  document.querySelector( 'main' ).insertAdjacentHTML( 'afterbegin', html );

  // Listen for close button click
  toolbox.event.on( button , 'click', dismissNotice )

  // Dismiss notice on close
  function dismissNotice( event ) {

    // Prevent default behavior
    event.preventDefault();

    // Cache notice element
    var noticeElem = selector.querySelector( '.' + options.noticeClass );

    // Remove notice from page
    selector.removeChild( noticeElem );

    // Set cookie to prevent it from returning
    document.cookie = cookieName + '=true; expires=Fri, 31 Dec 9999 23:59:59 GMT; path=/';
    
    toolbox.event.off( button )

  }

  // Check for cookie by name
  function getCookie( name ) {
    var value = '; ' + document.cookie;
    var parts = value.split( '; ' + name + '=' );
    if ( parts.length == 2 ) return parts.pop().split( ';' ).shift();
  }

  // Delete a cookie by setting the date of expiry to yesterday
  function deleteCookie( name ) {
    var date = new Date();
    date.setDate( date.getDate() -1 );
    document.cookie = escape( name ) + '=;expires=' + date;
  }

};

// Public API
module.exports = notice;
