/**
 * Sticky 0.0.3
 * Compose sticky elements module
 * @author Kyle Foster (@hkfoster)
 * @license MIT
 **/

// Dependencies
var toolbox  = require( 'compose-toolbox' ),
    fromTop  = toolbox.fromTop

// Public API function
var sticky = function( element, settings ) {

  // Overridable defaults
  var defaults = {
    topPadding  : false,
    initWidth   : '700px',
    stickyClass : 'sticky',
    anchorPoint : null
  };

  // Scoped variables
  var options  = toolbox.merge( defaults, settings ),
      selector = document.querySelector( element );

  // If selector is not present
  if ( !selector ) {

    // Abort
    return false;

  // Otherwise attach listeners
  } else {

    // Scoped variables
    var topPadding = ( options.topPadding === true ) ? parseInt( window.getComputedStyle( selector, null ).getPropertyValue( 'padding-top' ) ) : 0,
        widthQuery = window.matchMedia( '(min-width: ' + options.initWidth + ')' ),
        topOffset  = fromTop( selector ) + topPadding,
        elemHeight = selector.offsetHeight,
        anchorInit = options.anchorPoint,
        docBody    = document.body,
        resizeHandler = toolbox.event.resize( resized ),
        scrollHandler = toolbox.event.scroll( scrolled ),
        docHeight,
        winHeight;

    // Call listener function explicitly at run time
    queryHandler( widthQuery );

    // Attach listener function to listen in on state changes
    widthQuery.addListener( queryHandler );

  }

  // Media query handler function
  function queryHandler( condition ) {

    // Call resize listener function explicitly at run time
    resized()

    // Call scroll listener function explicitly at run time
    scrolled();
    
    // Reset styles
    if ( !condition.matches ) docBody.classList.remove( 'sticky' )

    // Remove resize listener
    resizeHandler.toggle( condition.matches )

    // Remove scroll listener
    scrollHandler.toggle( condition.matches )

  }

  // Resize handler function
  function resized() {

    // Update document height variable
    docHeight = document.body.scrollHeight;

    // Update window height variable
    winHeight = window.innerHeight;

  }

  // Scroll handler function
  function scrolled() {

    // Scoped variables
    var newScrollY = window.pageYOffset,
        pastOffset = newScrollY > topOffset,
        anchored   = ( anchorInit ) ? newScrollY >= docHeight - elemHeight - anchorInit + topPadding : null;

    // Where the magic happens
    if ( pastOffset && !anchored ) {
      docBody.classList.remove( 'anchored' );
      docBody.classList.add( 'sticky' );
    } else if ( pastOffset && anchored ) {
      docBody.classList.remove( 'sticky' );
      docBody.classList.add( 'anchored' );
    } else {
      docBody.classList.remove( 'sticky' );
    }

  }

};

// Public API
module.exports = sticky;
