/**
 * Scoped QuerySelector polyfill
 * @source https://github.com/lazd/scopedQuerySelectorShim
 * @author Larry Davis ( @lazd )
 * @license BSD
 */
( function() {

  // Throw error on super old browsers
  if ( !HTMLElement.prototype.querySelectorAll ) {
    throw new Error( 'rootedQuerySelectorAll: This polyfill can only be used with browsers that support querySelectorAll' );
  }

  // Create temporary element to query against and test for :scope support
  var container = document.createElement( 'div' );

  // Check if the browser supports :scope
  try {

    // Browser supports :scope, do nothing
    container.querySelectorAll( ':scope *' );

  // Otherwise
  } catch ( e ) {

    // Match usage of scope
    var scopeRE = /^\s*:scope/gi;

    // Overrides
    function overrideNodeMethod( prototype, methodName ) {

      // Store the old method for use later
      var oldMethod = prototype[ methodName ];

      // Override the method
      prototype[ methodName ] = function( query ) {

        var gaveContainer = false,
            gaveId        = false,
            nodeList;

        if ( query.match( scopeRE ) ) {

          // Remove :scope
          query = query.replace( scopeRE, '' );

          if ( !this.parentNode ) {

            // Add to temporary container
            container.appendChild( this );
            gaveContainer = true;

          }

          parentNode = this.parentNode;

          if ( !this.id ) {

            // Give temporary ID
            this.id = 'rootedQuerySelector_id_' + new Date().getTime();
            gaveId = true;

          }

          // Find elements against parent node
          nodeList = oldMethod.call( parentNode, '#' + this.id + ' ' + query );

          // Reset the ID
          if ( gaveId ) {
            this.id = '';
          }

          // Remove from temporary container
          if ( gaveContainer ) {
            container.removeChild( this );
          }

          return nodeList;

        } else {

          // No immediate child selector used
          return oldMethod.call( this, query );

        }
      };
    }

    // Browser doesnt support :scope, add polyfill
    overrideNodeMethod( HTMLElement.prototype, 'querySelector' );
    overrideNodeMethod( HTMLElement.prototype, 'querySelectorAll' );

  }
})();