module Ratchet
  module ApplicationHelper

    # Set custom favicon
    def favicon(&block)
      content_for :favicon, &block
    end

    # Set custom logo
    def logo(&block)
      content_for :logo, &block
    end

    # Set custom top navigation
    def top_nav(&block)
      content_for :top_nav, &block
    end

    # Set custom top navigation for app links
    def app_nav(&block)
      content_for :app_nav, &block
    end

    # Blank slate layout
    def blank(&block)
      content_for :blank, &block
    end

    # Blank slate layout
    def footer(&block)
      content_for :footer, &block
    end

    # Set custom page title
    def title(title = nil)
      title ? content_for(:title) { title + " | " + Site.name } : content_for(:title).presence
    end

    # Set custom page meta description
    def description(description = nil)
      description ? content_for(:description) { description } : content_for(:description).presence
    end

    # Set custom page meta keywords
    def keywords(keywords = nil)
      keywords ? content_for(:keywords) { keywords } : content_for(:keywords).presence
    end

    # Set custom page selector class
    def page_class(*classes)
      @classes = [] if @classes.nil?
      @classes += classes
      @classes.uniq!
      nil
    end

    # Consolidated page class output
    def page_classes
      page_class = @classes.map(&:to_s).join(" ") rescue nil
      [page_class ].reject(&:blank?).join(" ")
    end

    def deployment_name(name)
      Site.deployment_data['deployments'][name][:name]
    end

    # Main section class output
    def main_class( classnames = nil )
      if ( classnames )
        @main_classes ||= ''
        @main_classes = @main_classes + ' ' + classnames
        @main_classes.strip!
      else
        @main_classes || ''
      end
    end

    def number_to_currency(value)
      ActionController::Base.helpers.number_to_currency(value, unit: '$')
    end

  end
end
