module Ratchet
  module IconHelper

    def deployment_info(name)
      deployment = deployments[name.downcase]

      if deployment.nil? && !Rails.env.production?
        raise %Q{No deployment type "#{name}" exists.}
      end
        
      deployment
    end

    def deployments
      Site.deployment_data['deployments']
    end

    def deployment_graphic
      Site.deployment_icon
    end

    def grid_bg(options={})
      options = {
        scale: true,
        class: "svg-bg bottom centered",
        "aria-hidden" => true
      }.merge(options)

      use_svg "graphics/grid", options
    end

    def topology_desc(part, deployment_name)
      parts = Site.deployment_data['parts']
      if parts[deployment_name] && parts[deployment_name][part]
        parts[deployment_name][part]
      else
        parts[part]
      end
    end

    def deployment_text(text, options={})
      options = {
        x: deployment_graphic.width.to_f / 2,
        y: deployment_graphic.height.to_f / 2,
        fill: "currentColor",
        "font-weight" => 700,
        "font-size" => "57px",
        "text-anchor" => "middle",
        "dominant-baseline" =>"central",
        "alignment-baseline" => "central"
      }.merge(options)

      content_tag(:text, text, options).html_safe
    end

    def deployment_topology(name, options={})
      data = deployment_info(name)

      components = data[:topology].map do |item|
        Esvg.find_symbol("topology/#{item}")
      end

      base = 153 # height of top plane
      options[:spacing] ||= 10  # space between

      # Find height of each section
      heights = components.map(&:height).map { |h| h - base + options[:spacing] }

      # Start coordinates at 0
      y = [0].concat heights

      # Add previous height total to create next coordinate
      y = y.map.with_index { |h, i| y[0..i].reduce(:+) }

      # Full height = last calculated coordinate + base (minus the additional space)
      height = base + y.pop - options[:spacing]

      use = components.map.with_index do |c, i|
        part_name = c.name.sub('topology-','')
        c.use_tag(y: y[i], width: c.width, height: c.height, class:'capsule', "aria-label" => topology_desc(part_name, name.downcase))
      end.reverse.join

      attr = {
        version: "1.1",
        preserveAspectRatio: "xMidYMid meet",
        viewBox: "0 0 #{components.last.width} #{height}",
        'aria-label' => "Topology of a #{data[:name]} deployment"
      }.merge(options)

      content_tag(:svg, attr) { use.html_safe }
    end

    def deployment_svg(name, options={})
      data = deployment_info(name)
      (options[:use] ||= {})
      options[:use][:stroke] ||= options.delete(:stroke) || "currentColor"
      options[:use][:stroke_width] ||= options.delete(:stroke_width) || 4
      options[:use][:class] ||= "deployment-icon-hex #{options[:use][:class]}".strip

      options[:fill]    ||= "url(##{data[:gradient]})"
      options[:color]   ||= "#fff"
      options[:content] ||= deployment_text(data[:short_name], options.delete(:text) || {})

      deployment_graphic.use(options).html_safe
    end

    def deployment_icon(name, options={})
      options[:stroke_width] ||= 8
      options[:text] ||= { "font-weight" => 600, "font-size" => "76px" }
      deployment_svg name, options
    end
  end
end
